@@ -425,6 +425,8 @@ create_menu_bar_and_toolbar (VinagreWindow *window,
 		      0);
 
   window->priv->toolbar = gtk_ui_manager_get_widget (manager, "/ToolBar");
+  gtk_style_context_add_class (gtk_widget_get_style_context (window->priv->toolbar),
+                               GTK_STYLE_CLASS_PRIMARY_TOOLBAR);
   gtk_widget_hide (window->priv->toolbar);
   gtk_box_pack_start (GTK_BOX (main_box),
 		      window->priv->toolbar,
